@@ -9,6 +9,10 @@ from rdarrays import chron
 from rdarrays import recall
 
 from dependence import normal
-from dependence import corru
+from dependence import cgauss
 
-from shrinkage import shrink
\ No newline at end of file
+from shrinkage import shrink
+
+from edf import makeedf
+
+from kde import fitkde
\ No newline at end of file
